@@ -28,6 +28,9 @@ typedef enum {
 	DivEqual,
 	ModEqual,
 	StringAddEqual,
+	LeftShiftEqual,
+	RightShiftEqual,
+	StringMulEqual,
 	GreaterEqual,
 	LessEqual,
 	EqualEqual,
@@ -178,6 +181,7 @@ typedef enum {
 	HereDocumentTag,
 	HereDocumentRawTag,
 	HereDocumentExecTag,
+	HereDocumentBareTag,
 	RawHereDocument,
 	HereDocument,
 	HereDocumentEnd,
