@@ -15,18 +15,21 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::Glob, Enum::Token::Kind::Operator, "Glob", "*"},
 	{Enum::Token::Type::BitNot, Enum::Token::Kind::Operator, "BitNot", "~"},
 	{Enum::Token::Type::BitOr, Enum::Token::Kind::Operator, "BitOr", "|"},
-	{Enum::Token::Type::Or, Enum::Token::Kind::Operator, "Or", "or"},
+	{Enum::Token::Type::AlphabetOr, Enum::Token::Kind::Operator, "AlphabetOr", "or"},
 	{Enum::Token::Type::BitAnd, Enum::Token::Kind::Operator, "BitAnd", "&"},
-	{Enum::Token::Type::And, Enum::Token::Kind::Operator, "And", "and"},
+	{Enum::Token::Type::AlphabetAnd, Enum::Token::Kind::Operator, "AlphabetAnd", "and"},
 	{Enum::Token::Type::BitXOr, Enum::Token::Kind::Operator, "BitXOr", "^"},
-	{Enum::Token::Type::XOr, Enum::Token::Kind::Operator, "XOr", "xor"},
+	{Enum::Token::Type::AlphabetXOr, Enum::Token::Kind::Operator, "AlphabetXOr", "xor"},
 	{Enum::Token::Type::StringMul, Enum::Token::Kind::Operator, "StringMul", "x"},
 	{Enum::Token::Type::AddEqual, Enum::Token::Kind::Assign, "AddEqual", "+="},
 	{Enum::Token::Type::SubEqual, Enum::Token::Kind::Assign, "SubEqual", "-="},
 	{Enum::Token::Type::MulEqual, Enum::Token::Kind::Assign, "MulEqual", "*="},
 	{Enum::Token::Type::DivEqual, Enum::Token::Kind::Assign, "DivEqual", "/="},
 	{Enum::Token::Type::ModEqual, Enum::Token::Kind::Assign, "ModEqual", "%="},
-	{Enum::Token::Type::StringAdd, Enum::Token::Kind::Assign, "StringAdd", ".="},
+	{Enum::Token::Type::StringAddEqual, Enum::Token::Kind::Assign, "StringAddEqual", ".="},
+	{Enum::Token::Type::LeftShiftEqual, Enum::Token::Kind::Assign, "LeftShiftEqual", "<<="},
+	{Enum::Token::Type::RightShiftEqual, Enum::Token::Kind::Assign, "RightShiftEqual", ">>="},
+	{Enum::Token::Type::StringMulEqual, Enum::Token::Kind::Assign, "StringMulEqual", "x="},
 	{Enum::Token::Type::GreaterEqual, Enum::Token::Kind::Operator, "GreaterEqual", ">="},
 	{Enum::Token::Type::LessEqual, Enum::Token::Kind::Operator, "LessEqual", "<="},
 	{Enum::Token::Type::EqualEqual, Enum::Token::Kind::Operator, "EqualEqual", "=="},
@@ -36,7 +39,6 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::RegOK, Enum::Token::Kind::Operator, "RegOK", "=~"},
 	{Enum::Token::Type::RegNot, Enum::Token::Kind::Operator, "RegNot", "!~"},
 	{Enum::Token::Type::NotEqual, Enum::Token::Kind::Operator, "NotEqual", "!="},
-	{Enum::Token::Type::ArraySize, Enum::Token::Kind::Operator, "ArraySize", "$#"},
 	{Enum::Token::Type::StringLess, Enum::Token::Kind::Operator, "StringLess", "lt"},
 	{Enum::Token::Type::StringLessEqual, Enum::Token::Kind::Operator, "StringLessEqual", "le"},
 	{Enum::Token::Type::StringGreater, Enum::Token::Kind::Operator, "StringGreater", "gt"},
@@ -65,9 +67,10 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::FunctionDecl, Enum::Token::Kind::Decl, "FunctionDecl", "sub"},
 	{Enum::Token::Type::Method, Enum::Token::Kind::Function, "Method", ""},
 	{Enum::Token::Type::Assign, Enum::Token::Kind::Assign, "Assign", "="},
+	{Enum::Token::Type::ArraySize, Enum::Token::Kind::SingleTerm, "ArraySize", "$#"},
 	{Enum::Token::Type::Is, Enum::Token::Kind::SingleTerm, "Is", ""},
-	{Enum::Token::Type::IsNot, Enum::Token::Kind::SingleTerm, "IsNot", "!"},
-	{Enum::Token::Type::Not, Enum::Token::Kind::SingleTerm, "Not", "not"},
+	{Enum::Token::Type::Not, Enum::Token::Kind::SingleTerm, "Not", "!"},
+	{Enum::Token::Type::AlphabetNot, Enum::Token::Kind::SingleTerm, "AlphabetNot", "not"},
 	{Enum::Token::Type::BuiltinFunc, Enum::Token::Kind::Function, "BuiltinFunc", "chomp"},
 	{Enum::Token::Type::BuiltinFunc, Enum::Token::Kind::Function, "BuiltinFunc", "chop"},
 	{Enum::Token::Type::BuiltinFunc, Enum::Token::Kind::Function, "BuiltinFunc", "chr"},
@@ -272,13 +275,13 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::STDIN, Enum::Token::Kind::Handle, "STDIN", "STDIN"},
 	{Enum::Token::Type::STDOUT, Enum::Token::Kind::Handle, "STDOUT", "STDOUT"},
 	{Enum::Token::Type::STDERR, Enum::Token::Kind::Handle, "STDERR", "STDERR"},
-	{Enum::Token::Type::Redo, Enum::Token::Kind::Redo, "Redo", "redo"},
-	{Enum::Token::Type::Next, Enum::Token::Kind::Next, "Next", "next"},
-	{Enum::Token::Type::Last, Enum::Token::Kind::Last, "Last", "last"},
-	{Enum::Token::Type::Goto, Enum::Token::Kind::Goto, "Goto", "goto"},
-	{Enum::Token::Type::Continue, Enum::Token::Kind::Continue, "Continue", "continue"},
+	{Enum::Token::Type::Redo, Enum::Token::Kind::Control, "Redo", "redo"},
+	{Enum::Token::Type::Next, Enum::Token::Kind::Control, "Next", "next"},
+	{Enum::Token::Type::Last, Enum::Token::Kind::Control, "Last", "last"},
+	{Enum::Token::Type::Goto, Enum::Token::Kind::Control, "Goto", "goto"},
+	{Enum::Token::Type::Continue, Enum::Token::Kind::Control, "Continue", "continue"},
 	{Enum::Token::Type::Do, Enum::Token::Kind::Do, "Do", "do"},
-	{Enum::Token::Type::Break, Enum::Token::Kind::Break, "Break", "break"},
+	{Enum::Token::Type::Break, Enum::Token::Kind::Control, "Break", "break"},
 	{Enum::Token::Type::Handle, Enum::Token::Kind::Handle, "Handle", "-b"},
 	{Enum::Token::Type::Handle, Enum::Token::Kind::Handle, "Handle", "-c"},
 	{Enum::Token::Type::Handle, Enum::Token::Kind::Handle, "Handle", "-d"},
@@ -332,6 +335,7 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::ArrayDereference, Enum::Token::Kind::Modifier, "ArrayDereference", "@{"},
 	{Enum::Token::Type::HashDereference, Enum::Token::Kind::Modifier, "HashDereference", "%{"},
 	{Enum::Token::Type::ScalarDereference, Enum::Token::Kind::Modifier, "ScalarDereference", "${"},
+	{Enum::Token::Type::CodeDereference, Enum::Token::Kind::Modifier, "CodeDereference", "&{"},
 	{Enum::Token::Type::ShortScalarDereference, Enum::Token::Kind::Modifier, "ShortScalarDereference", ""},
 	{Enum::Token::Type::ShortArrayDereference, Enum::Token::Kind::Modifier, "ShortArrayDereference", "@$"},
 	{Enum::Token::Type::ShortHashDereference, Enum::Token::Kind::Modifier, "ShortHashDereference", "%$"},
@@ -448,6 +452,7 @@ TokenInfo decl_tokens[] = {
 	{Enum::Token::Type::HereDocumentTag, Enum::Token::Kind::Term, "HereDocumentTag", ""},
 	{Enum::Token::Type::HereDocumentRawTag, Enum::Token::Kind::Term, "HereDocumentRawTag", ""},
 	{Enum::Token::Type::HereDocumentExecTag, Enum::Token::Kind::Term, "HereDocumentExecTag", ""},
+	{Enum::Token::Type::HereDocumentBareTag, Enum::Token::Kind::Term, "HereDocumentBareTag", ""},
 	{Enum::Token::Type::RawHereDocument, Enum::Token::Kind::Term, "RawHereDocument", ""},
 	{Enum::Token::Type::HereDocument, Enum::Token::Kind::Term, "HereDocument", ""},
 	{Enum::Token::Type::HereDocumentEnd, Enum::Token::Kind::Term, "HereDocumentEnd", ""},
@@ -497,17 +502,21 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::Glob, Enum::Token::Kind::Operator, "Glob", "*"},
 	{Enum::Token::Type::BitNot, Enum::Token::Kind::Operator, "BitNot", "~"},
 	{Enum::Token::Type::BitOr, Enum::Token::Kind::Operator, "BitOr", "|"},
-	{Enum::Token::Type::Or, Enum::Token::Kind::Operator, "Or", "or"},
+	{Enum::Token::Type::AlphabetOr, Enum::Token::Kind::Operator, "AlphabetOr", "or"},
 	{Enum::Token::Type::BitAnd, Enum::Token::Kind::Operator, "BitAnd", "&"},
-	{Enum::Token::Type::And, Enum::Token::Kind::Operator, "And", "and"},
+	{Enum::Token::Type::AlphabetAnd, Enum::Token::Kind::Operator, "AlphabetAnd", "and"},
 	{Enum::Token::Type::BitXOr, Enum::Token::Kind::Operator, "BitXOr", "^"},
-	{Enum::Token::Type::XOr, Enum::Token::Kind::Operator, "XOr", "xor"},
+	{Enum::Token::Type::AlphabetXOr, Enum::Token::Kind::Operator, "AlphabetXOr", "xor"},
 	{Enum::Token::Type::StringMul, Enum::Token::Kind::Operator, "StringMul", "x"},
 	{Enum::Token::Type::AddEqual, Enum::Token::Kind::Assign, "AddEqual", "+="},
 	{Enum::Token::Type::SubEqual, Enum::Token::Kind::Assign, "SubEqual", "-="},
 	{Enum::Token::Type::MulEqual, Enum::Token::Kind::Assign, "MulEqual", "*="},
 	{Enum::Token::Type::DivEqual, Enum::Token::Kind::Assign, "DivEqual", "/="},
 	{Enum::Token::Type::ModEqual, Enum::Token::Kind::Assign, "ModEqual", "%="},
+	{Enum::Token::Type::StringAddEqual, Enum::Token::Kind::Assign, "StringAddEqual", ".="},
+	{Enum::Token::Type::LeftShiftEqual, Enum::Token::Kind::Assign, "LeftShiftEqual", "<<="},
+	{Enum::Token::Type::RightShiftEqual, Enum::Token::Kind::Assign, "RightShiftEqual", ">>="},
+	{Enum::Token::Type::StringMulEqual, Enum::Token::Kind::Assign, "StringMulEqual", "x="},
 	{Enum::Token::Type::GreaterEqual, Enum::Token::Kind::Operator, "GreaterEqual", ">="},
 	{Enum::Token::Type::LessEqual, Enum::Token::Kind::Operator, "LessEqual", "<="},
 	{Enum::Token::Type::EqualEqual, Enum::Token::Kind::Operator, "EqualEqual", "=="},
@@ -517,7 +526,6 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::RegOK, Enum::Token::Kind::Operator, "RegOK", "=~"},
 	{Enum::Token::Type::RegNot, Enum::Token::Kind::Operator, "RegNot", "!~"},
 	{Enum::Token::Type::NotEqual, Enum::Token::Kind::Operator, "NotEqual", "!="},
-	{Enum::Token::Type::ArraySize, Enum::Token::Kind::Operator, "ArraySize", "$#"},
 	{Enum::Token::Type::StringLess, Enum::Token::Kind::Operator, "StringLess", "lt"},
 	{Enum::Token::Type::StringLessEqual, Enum::Token::Kind::Operator, "StringLessEqual", "le"},
 	{Enum::Token::Type::StringGreater, Enum::Token::Kind::Operator, "StringGreater", "gt"},
@@ -532,6 +540,8 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::DefaultEqual, Enum::Token::Kind::Assign, "DefaultEqual", "//="},
 	{Enum::Token::Type::LeftShift, Enum::Token::Kind::Operator, "LeftShift", "<<"},
 	{Enum::Token::Type::RightShift, Enum::Token::Kind::Operator, "RightShift", ">>"},
+	{Enum::Token::Type::And, Enum::Token::Kind::Operator, "And", "&&"},
+	{Enum::Token::Type::Or, Enum::Token::Kind::Operator, "Or", "||"},
 	{Enum::Token::Type::AndBitEqual, Enum::Token::Kind::Assign, "AndBitEqual", "&="},
 	{Enum::Token::Type::OrBitEqual, Enum::Token::Kind::Assign, "OrBitEqual", "|="},
 	{Enum::Token::Type::NotBitEqual, Enum::Token::Kind::Assign, "NotBitEqual", "^="},
@@ -544,9 +554,10 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::FunctionDecl, Enum::Token::Kind::Decl, "FunctionDecl", "sub"},
 	{Enum::Token::Type::Method, Enum::Token::Kind::Function, "Method", ""},
 	{Enum::Token::Type::Assign, Enum::Token::Kind::Assign, "Assign", "="},
+	{Enum::Token::Type::ArraySize, Enum::Token::Kind::SingleTerm, "ArraySize", "$#"},
 	{Enum::Token::Type::Is, Enum::Token::Kind::SingleTerm, "Is", ""},
-	{Enum::Token::Type::IsNot, Enum::Token::Kind::SingleTerm, "IsNot", "!"},
-	{Enum::Token::Type::Not, Enum::Token::Kind::SingleTerm, "Not", "not"},
+	{Enum::Token::Type::Not, Enum::Token::Kind::SingleTerm, "Not", "!"},
+	{Enum::Token::Type::AlphabetNot, Enum::Token::Kind::SingleTerm, "AlphabetNot", "not"},
 	{Enum::Token::Type::BuiltinFunc, Enum::Token::Kind::Function, "BuiltinFunc", "chomp"},
 	{Enum::Token::Type::RequireDecl, Enum::Token::Kind::Decl, "RequireDecl", "require"},
 	{Enum::Token::Type::Import, Enum::Token::Kind::Import, "Import", "import"},
@@ -559,13 +570,13 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::STDIN, Enum::Token::Kind::Handle, "STDIN", "STDIN"},
 	{Enum::Token::Type::STDOUT, Enum::Token::Kind::Handle, "STDOUT", "STDOUT"},
 	{Enum::Token::Type::STDERR, Enum::Token::Kind::Handle, "STDERR", "STDERR"},
-	{Enum::Token::Type::Redo, Enum::Token::Kind::Redo, "Redo", "redo"},
-	{Enum::Token::Type::Next, Enum::Token::Kind::Next, "Next", "next"},
-	{Enum::Token::Type::Last, Enum::Token::Kind::Last, "Last", "last"},
-	{Enum::Token::Type::Goto, Enum::Token::Kind::Goto, "Goto", "goto"},
-	{Enum::Token::Type::Continue, Enum::Token::Kind::Continue, "Continue", "continue"},
+	{Enum::Token::Type::Redo, Enum::Token::Kind::Control, "Redo", "redo"},
+	{Enum::Token::Type::Next, Enum::Token::Kind::Control, "Next", "next"},
+	{Enum::Token::Type::Last, Enum::Token::Kind::Control, "Last", "last"},
+	{Enum::Token::Type::Goto, Enum::Token::Kind::Control, "Goto", "goto"},
+	{Enum::Token::Type::Continue, Enum::Token::Kind::Control, "Continue", "continue"},
 	{Enum::Token::Type::Do, Enum::Token::Kind::Do, "Do", "do"},
-	{Enum::Token::Type::Break, Enum::Token::Kind::Break, "Break", "break"},
+	{Enum::Token::Type::Break, Enum::Token::Kind::Control, "Break", "break"},
 	{Enum::Token::Type::Handle, Enum::Token::Kind::Handle, "Handle", "-b"},
 	{Enum::Token::Type::LocalDecl, Enum::Token::Kind::Decl, "LocalDecl", "local"},
 	{Enum::Token::Type::OurDecl, Enum::Token::Kind::Decl, "OurDecl", "our"},
@@ -593,6 +604,7 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::ArrayDereference, Enum::Token::Kind::Modifier, "ArrayDereference", "@{"},
 	{Enum::Token::Type::HashDereference, Enum::Token::Kind::Modifier, "HashDereference", "%{"},
 	{Enum::Token::Type::ScalarDereference, Enum::Token::Kind::Modifier, "ScalarDereference", "${"},
+	{Enum::Token::Type::CodeDereference, Enum::Token::Kind::Modifier, "CodeDereference", "&{"},
 	{Enum::Token::Type::ShortScalarDereference, Enum::Token::Kind::Modifier, "ShortScalarDereference", ""},
 	{Enum::Token::Type::ShortArrayDereference, Enum::Token::Kind::Modifier, "ShortArrayDereference", "@$"},
 	{Enum::Token::Type::ShortHashDereference, Enum::Token::Kind::Modifier, "ShortHashDereference", "%$"},
@@ -655,6 +667,7 @@ TokenInfo type_to_info[] = {
 	{Enum::Token::Type::HereDocumentTag, Enum::Token::Kind::Term, "HereDocumentTag", ""},
 	{Enum::Token::Type::HereDocumentRawTag, Enum::Token::Kind::Term, "HereDocumentRawTag", ""},
 	{Enum::Token::Type::HereDocumentExecTag, Enum::Token::Kind::Term, "HereDocumentExecTag", ""},
+	{Enum::Token::Type::HereDocumentBareTag, Enum::Token::Kind::Term, "HereDocumentBareTag", ""},
 	{Enum::Token::Type::RawHereDocument, Enum::Token::Kind::Term, "RawHereDocument", ""},
 	{Enum::Token::Type::HereDocument, Enum::Token::Kind::Term, "HereDocument", ""},
 	{Enum::Token::Type::HereDocumentEnd, Enum::Token::Kind::Term, "HereDocumentEnd", ""},
